==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE54S.sql <==
/****************************************************************************/
/* GE54 ( 帳票定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE54 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID           */
 , LISTID           VARCHAR2 (   10 )                   NOT NULL            /*  20 帳票ID           */
 , LISTNAME         VARCHAR2 (  100 )                                       /*  30 帳票名称         */
 , MODELDIR         VARCHAR2 (  100 )                   NOT NULL            /*  40 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        VARCHAR2 (   20 )                   NOT NULL            /*  50 雛型ﾌｧｲﾙ名       */
 , FGCUT            VARCHAR2 (    1 )                                       /*  60 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , HSQL             VARCHAR2 ( 4000 )                                       /*  70 ﾍｯﾀﾞｰSQL         */
 , FSQL             VARCHAR2 ( 4000 )                                       /*  80 ﾌｯﾀｰSQL          */
 , BSQL             VARCHAR2 ( 4000 )                                       /*  90 ﾎﾞﾃﾞｨSQL         */
 , COMMENTS         VARCHAR2 (  500 )                                       /* 100 ｺﾒﾝﾄ             */
 , FGLOCAL          VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /* 130 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         VARCHAR2 (   20 )                                       /* 140 設変番号         */
 , OPTIONS          VARCHAR2 ( 1000 )                                       /* 150 オプション       */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時         */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG           */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG         */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者           */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時         */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG           */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG         */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者           */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

==> openGion7.2.9.5_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE54S.sql <==
/****************************************************************************/
/* GE54 ( 帳票定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2020/11/27 10:18:50                                            */
/****************************************************************************/

CREATE TABLE GE54 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID           */
 , LISTID           VARCHAR2 (   10 )                   NOT NULL            /*  20 帳票ID           */
 , LISTNAME         VARCHAR2 (  100 )                                       /*  30 帳票名称         */
 , MODELDIR         VARCHAR2 (  100 )                   NOT NULL            /*  40 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        VARCHAR2 (   20 )                   NOT NULL            /*  50 雛型ﾌｧｲﾙ名       */
 , FGCUT            VARCHAR2 (    1 )                                       /*  60 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , HSQL             VARCHAR2 ( 4000 )                                       /*  70 ﾍｯﾀﾞｰSQL         */
 , FSQL             VARCHAR2 ( 4000 )                                       /*  80 ﾌｯﾀｰSQL          */
 , BSQL             VARCHAR2 ( 4000 )                                       /*  90 ﾎﾞﾃﾞｨSQL         */
 , COMMENTS         VARCHAR2 (  500 )                                       /* 100 ｺﾒﾝﾄ             */
 , FGLOCAL          VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /* 130 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         VARCHAR2 (   20 )                                       /* 140 設変番号         */
 , OPTIONS          VARCHAR2 ( 1000 )                                       /* 150 オプション       */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 作成日時         */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG           */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG         */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者           */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時         */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG           */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG         */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者           */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
